@@ -54,8 +54,6 @@ class IListener:public svn::ContextListener
     friend class kdesvnd_dcop;
 
     kdesvnd_dcop*m_back;
-
-    PwStorage pws;
 public:
     IListener(kdesvnd_dcop*p);
     virtual ~IListener();
@@ -65,6 +63,7 @@ public:
                                   QString & password,
                                   bool & maySave);
     virtual bool contextGetSavedLogin (const QString & realm,QString & username,QString & password);
+    virtual bool contextGetCachedLogin (const QString & realm,QString & username,QString & password);
 
     virtual void contextNotify (const char *path,
                                 svn_wc_notify_action_t action,
@@ -305,8 +304,8 @@ bool kdesvnd_dcop::isRepository(const KURL&url)
         svn::Revision where = svn::Revision::HEAD;
         svn::StatusEntries dlist;
         try {
-            m_Listener->m_Svnclient->status("file://"+cleanUrl(url),false,false,false,false,where);
-        } catch (svn::ClientException e) {
+            m_Listener->m_Svnclient->status("file://"+cleanUrl(url),svn::DepthEmpty,false,false,false,where);
+        } catch (const svn::ClientException&e) {
             kdDebug()<< e.msg()<<endl;
             return false;
         }
@@ -327,8 +326,8 @@ bool kdesvnd_dcop::isWorkingCopy(const KURL&_url,QString&base)
     svn::Revision rev(svn_opt_revision_unspecified);
     svn::InfoEntries e;
     try {
-        e = m_Listener->m_Svnclient->info(cleanUrl(url),false,rev,peg);
-    } catch (svn::ClientException e) {
+        e = m_Listener->m_Svnclient->info(cleanUrl(url),svn::DepthEmpty,rev,peg);
+    } catch (const svn::ClientException&e) {
         kdDebug()<< e.msg()<<endl;
         return false;
     }
@@ -338,7 +337,12 @@ bool kdesvnd_dcop::isWorkingCopy(const KURL&_url,QString&base)
 
 bool IListener::contextGetSavedLogin (const QString & realm,QString & username,QString & password)
 {
-    pws.getLogin(realm,username,password);
+    PwStorage::self()->getLogin(realm,username,password);
+    return true;
+}
+
+bool IListener::contextGetCachedLogin (const QString & realm,QString & username,QString & password)
+{
     return true;
 }
 
@@ -356,7 +360,7 @@ bool IListener::contextGetLogin (const QString & realm,
     password = res[1];
     maySave = (res[2]=="true");
     if (maySave && Kdesvnsettings::passwords_in_wallet() ) {
-        pws.setLogin(realm,username,password);
+        PwStorage::self()->setLogin(realm,username,password);
         maySave=false;
     }
     return true;
@@ -427,14 +431,14 @@ bool IListener::contextSslClientCertPrompt (QString & certFile)
 
 bool IListener::contextLoadSslClientCertPw(QString&password,const QString&realm)
 {
-    return pws.getCertPw(realm,password);
+    return PwStorage::self()->getCertPw(realm,password);
 }
 
 bool IListener::contextSslClientCertPwPrompt (QString & password,
                                    const QString & realm, bool & maySave)
 {
     maySave=false;
-    if (pws.getCertPw(realm,password)) {
+    if (PwStorage::self()->getCertPw(realm,password)) {
         return true;
     }
     QStringList res = m_back->get_sslclientcertpw(realm);
@@ -445,7 +449,7 @@ bool IListener::contextSslClientCertPwPrompt (QString & password,
     maySave=res[1]==QString("true");
 
     if (maySave && Kdesvnsettings::passwords_in_wallet() ) {
-        pws.setCertPw(realm,password);
+        PwStorage::self()->setCertPw(realm,password);
         maySave=false;
     }
 
