@@ -195,8 +195,8 @@ void kio_svnProtocol::listDir(const KURL&url)
     }
 
     try {
-        dlist = m_pData->m_Svnclient->list(makeSvnUrl(url),rev,rev,false,false);
-    } catch (svn::ClientException e) {
+        dlist = m_pData->m_Svnclient->list(makeSvnUrl(url),rev,rev,svn::DepthImmediates,false);
+    } catch (const svn::ClientException&e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
         error(KIO::ERR_CANNOT_ENTER_DIRECTORY,ex);
@@ -232,11 +232,10 @@ void kio_svnProtocol::stat(const KURL& url)
     }
     svn::Revision peg = rev;
     bool dummy = false;
-    QString s = makeSvnUrl(url);
     svn::InfoEntries e;
     try {
-         e = m_pData->m_Svnclient->info(s,false,rev,peg);
-    } catch  (svn::ClientException e) {
+         e = m_pData->m_Svnclient->info(makeSvnUrl(url),svn::DepthEmpty,rev,peg);
+    } catch  (const svn::ClientException&e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,ex);
@@ -279,7 +278,7 @@ void kio_svnProtocol::get(const KURL& url)
     KioByteStream dstream(this,url.filename());
     try {
         m_pData->m_Svnclient->cat(dstream,makeSvnUrl(url),rev,rev);
-    } catch (svn::ClientException e) {
+    } catch (const svn::ClientException&e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,"Subversion error "+ex);
@@ -298,10 +297,10 @@ void kio_svnProtocol::mkdir(const KURL &url, int)
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    svn::Path p(makeSvnUrl(url));
     try {
+        svn::Path p(makeSvnUrl(url));
         m_pData->m_Svnclient->mkdir(p,getDefaultLog());
-    }catch (svn::ClientException e) {
+    }catch (const svn::ClientException&e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     kdDebug()<<"kio_svn::mkdir finished " << url << endl;
@@ -330,7 +329,7 @@ void kio_svnProtocol::rename(const KURL&src,const KURL&target,bool force)
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         m_pData->m_Svnclient->move(makeSvnUrl(src),makeSvnUrl(target),force);
-    }catch (svn::ClientException e) {
+    }catch (const svn::ClientException&e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     kdDebug()<<"kio_svn::rename finished" <<  endl;
@@ -350,7 +349,7 @@ void kio_svnProtocol::copy(const KURL&src,const KURL&dest,int permissions,bool o
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
         m_pData->m_Svnclient->copy(makeSvnUrl(src),rev,makeSvnUrl(dest));
-    }catch (svn::ClientException e) {
+    }catch (const svn::ClientException&e) {
         error( KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     m_pData->dispProgress=false;
@@ -367,11 +366,11 @@ void kio_svnProtocol::del(const KURL&src,bool isfile)
     if (rev == svn::Revision::UNDEFINED) {
         rev = svn::Revision::HEAD;
     }
-    svn::Targets target(makeSvnUrl(src));
     m_pData->m_CurrentContext->setLogMessage(getDefaultLog());
     try {
+        svn::Targets target(makeSvnUrl(src));
         m_pData->m_Svnclient->remove(target,false);
-    } catch (svn::ClientException e) {
+    } catch (const svn::ClientException&e) {
         QString ex = e.msg();
         kdDebug()<<ex<<endl;
         error( KIO::ERR_SLAVE_DEFINED,ex);
@@ -393,8 +392,8 @@ bool kio_svnProtocol::checkWc(const KURL&url)
     svn::Revision rev(svn_opt_revision_unspecified);
     svn::InfoEntries e;
     try {
-        e = m_pData->m_Svnclient->info(url.prettyURL(),false,rev,peg);
-    } catch (svn::ClientException e) {
+        e = m_pData->m_Svnclient->info(url.prettyURL(),svn::DepthEmpty,rev,peg);
+    } catch (const svn::ClientException&e) {
         if (SVN_ERR_WC_NOT_DIRECTORY==e.apr_err())
         {
             return false;
@@ -425,6 +424,9 @@ QString kio_svnProtocol::makeSvnUrl(const KURL&url,bool check_Wc)
     } else {
         res = proto+"://"+(user.isEmpty()?"":user+"@")+host+base;
     }
+    if (base.isEmpty()) {
+        throw svn::ClientException(QString("'")+res+QString("' is not a valid subversion url"));
+    }
     return res;
 }
 
@@ -642,10 +644,11 @@ void kio_svnProtocol::update(const KURL&url,int revnumber,const QString&revkind)
     svn::Path p(url.path());
     try {
         svn::Targets pathes(p.path());
-        // recursive second last parameter
-        // always update externals, too. (last parameter)
-        m_pData->m_Svnclient->update(pathes, where,true,false);
-    } catch (svn::ClientException e) {
+        // always update externals, too. (third last parameter)
+        // no unversioned items allowed (second last parameter)
+        // sticky depth (last parameter)
+        m_pData->m_Svnclient->update(pathes, where,svn::DepthInfinity,false,false,true);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
 }
@@ -656,8 +659,8 @@ void kio_svnProtocol::status(const KURL&wc,bool cR,bool rec)
     svn::StatusEntries dlist;
     try {
         //                                            rec all  up     noign
-        dlist = m_pData->m_Svnclient->status(wc.path(),rec,false,cR,false,where);
-    } catch (svn::ClientException e) {
+        dlist = m_pData->m_Svnclient->status(wc.path(),rec?svn::DepthInfinity:svn::DepthEmpty,false,cR,false,where);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
     }
@@ -714,8 +717,8 @@ void kio_svnProtocol::commit(const KURL::List&url)
     }
     svn::Revision nnum=svn::Revision::UNDEFINED;
     try {
-        nnum = m_pData->m_Svnclient->commit(svn::Targets(targets),msg,true,false);
-    } catch (svn::ClientException e) {
+        nnum = m_pData->m_Svnclient->commit(svn::Targets(targets),msg,svn::DepthInfinity,false);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     for (unsigned j=0;j<url.count();++j) {
@@ -741,11 +744,11 @@ void kio_svnProtocol::checkout(const KURL&src,const KURL&target,const int rev, c
 {
     svn::Revision where(rev,revstring);
     svn::Revision peg = svn::Revision::UNDEFINED;
-    KURL _src = makeSvnUrl(src);
     svn::Path _target(target.path());
     try {
-        m_pData->m_Svnclient->checkout(_src.url(),_target,where,peg,true,false);
-    } catch (svn::ClientException e) {
+        KURL _src = makeSvnUrl(src);
+        m_pData->m_Svnclient->checkout(_src.url(),_target,where,peg,svn::DepthInfinity,false,false);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
 }
@@ -759,8 +762,8 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
     for (unsigned j = 0; j<urls.count();++j) {
         logs = 0;
         try {
-            logs = m_pData->m_Svnclient->log(makeSvnUrl(urls[j]),start,end,true,true,0);
-        } catch (svn::ClientException e) {
+            logs = m_pData->m_Svnclient->log(makeSvnUrl(urls[j]),start,end,svn::Revision::UNDEFINED,true,true,0);
+        } catch (const svn::ClientException&e) {
             error(KIO::ERR_SLAVE_DEFINED,e.msg());
             break;
         }
@@ -806,8 +809,8 @@ void kio_svnProtocol::revert(const KURL::List&l)
     }
     svn::Targets target(list);
     try {
-        m_pData->m_Svnclient->revert(target,false);
-    } catch (svn::ClientException e) {
+        m_pData->m_Svnclient->revert(target,svn::DepthEmpty);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
 }
@@ -817,30 +820,30 @@ void kio_svnProtocol::wc_switch(const KURL&wc,const KURL&target,bool rec,int rev
     svn::Revision where(rev,revstring);
     svn::Path wc_path(wc.path());
     try {
-        m_pData->m_Svnclient->doSwitch(wc_path,makeSvnUrl(target.url()),where,rec);
-    } catch (svn::ClientException e) {
+        m_pData->m_Svnclient->doSwitch(wc_path,makeSvnUrl(target.url()),where,rec?svn::DepthInfinity:svn::DepthFiles);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
 }
 
 void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QString&rstring1,int rnum2, const QString&rstring2,bool rec)
 {
-    svn::Revision r1(rnum1,rstring1);
-    svn::Revision r2(rnum2,rstring2);
-    QString u1 = makeSvnUrl(uri1,true);
-    QString u2 = makeSvnUrl(uri2,true);
     QByteArray ex;
-    KTempDir tdir;
-    kdDebug() << "kio_ksvn::diff : " << u1 << " at revision " << r1.toString() << " with "
-        << u2 << " at revision " << r2.toString()
-        << endl ;
-
-    tdir.setAutoDelete(true);
     /// @todo read settings for diff (ignore contentype)
     try {
-        ex = m_pData->m_Svnclient->diff(svn::Path(tdir.name()),
-        u1,u2,r1, r2,rec,false,false,false);
-    } catch (svn::ClientException e) {
+        svn::Revision r1(rnum1,rstring1);
+        svn::Revision r2(rnum2,rstring2);
+        QString u1 = makeSvnUrl(uri1,true);
+        QString u2 = makeSvnUrl(uri2,true);
+        KTempDir tdir;
+        kdDebug() << "kio_ksvn::diff : " << u1 << " at revision " << r1.toString() << " with "
+            << u2 << " at revision " << r2.toString()
+            << endl ;
+
+        tdir.setAutoDelete(true);
+            ex = m_pData->m_Svnclient->diff(svn::Path(tdir.name()),
+                                            u1,u2,svn::Path(),r1, r2,rec?svn::DepthInfinity:svn::DepthEmpty,false,false,false);
+    } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
     }
@@ -854,10 +857,10 @@ void kio_svnProtocol::diff(const KURL&uri1,const KURL&uri2,int rnum1,const QStri
 
 void kio_svnProtocol::import(const KURL& repos, const KURL& wc)
 {
-    QString target = makeSvnUrl(repos);
-    QString path = wc.path();
     try {
-        m_pData->m_Svnclient->import(svn::Path(path),target,QString::null,true);
+        QString target = makeSvnUrl(repos);
+        QString path = wc.path();
+        m_pData->m_Svnclient->import(svn::Path(path),target,QString::null,svn::DepthInfinity,false,false);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
@@ -870,7 +873,7 @@ void kio_svnProtocol::add(const KURL& wc)
     QString path = wc.path();
     try {
                                                /* rec */
-        m_pData->m_Svnclient->add(svn::Path(path),true);
+        m_pData->m_Svnclient->add(svn::Path(path),svn::DepthInfinity);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
@@ -896,7 +899,8 @@ void kio_svnProtocol::wc_delete(const KURL::List&l)
 void kio_svnProtocol::wc_resolve(const KURL&url,bool recurse)
 {
     try {
-        m_pData->m_Svnclient->resolved(url.path(),recurse);
+        svn::Depth depth=recurse?svn::DepthInfinity:svn::DepthEmpty;
+        m_pData->m_Svnclient->resolve(url.path(),depth);
     } catch (const svn::ClientException&e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
         return;
