@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Rajko Albrecht                                  *
+ *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,6 +33,9 @@
 #include <sys/stat.h>
 #include <qvaluelist.h>
 
+namespace KIO
+{
+
 class KioSvnData;
 
 /**
@@ -47,6 +50,7 @@ public:
     virtual void stat(const KURL& url);
     virtual void get(const KURL& url);
     virtual void mkdir (const KURL &url, int permissions);
+    virtual void mkdir (const KURL::List &urls, int permissions);
     virtual void rename(const KURL&src,const KURL&target,bool force);
     virtual void del(const KURL&url,bool isfile);
     virtual void copy(const KURL&src,const KURL&dest,int permissions,bool overwrite);
@@ -55,7 +59,11 @@ public:
     virtual void revert(const KURL::List&);
     virtual void wc_switch(const KURL&,const KURL&,bool,int,const QString&);
     virtual void diff(const KURL&,const KURL&,int,const QString&,int, const QString&,bool);
+    virtual void import( const KURL& repos, const KURL& wc);
+    virtual void add(const KURL& wc);
+    virtual void wc_delete(const KURL::List&);
     virtual void special(const QByteArray& data);
+    virtual void wc_resolve(const KURL&,bool);
     /* looked on kio::svn from kdesdk */
     enum KSVN_METHOD {
         /* KURL repository, KURL target, int revnumber, QString revkind */
@@ -68,13 +76,17 @@ public:
         /* int revstart, QString revstartstring, int revend, QString revendstring, KURL::List */
         SVN_LOG=4,
         SVN_IMPORT=5,
+        /* KURL */
         SVN_ADD=6,
+        /*KURL::List */
         SVN_DEL=7,
         /* KURL::List */
         SVN_REVERT=8,
         /* KURL wc,bool checkRepos, bool recurse */
         SVN_STATUS=9,
+        /* KURL::List */
         SVN_MKDIR=10,
+        /* KURL, bool */
         SVN_RESOLVE=11,
         /* KURL working copy, KURL new_repository_url, bool recurse, int rev, QString revstring */
         SVN_SWITCH=12,
@@ -96,9 +108,13 @@ protected:
 private:
     KioSvnData*m_pData;
     bool createUDSEntry( const QString& filename, const QString& user, long long int size, bool isdir, time_t mtime, KIO::UDSEntry& entry);
-    static QString makeSvnUrl(const KURL&url);
+    QString makeSvnUrl(const KURL&url,bool check_wc=true);
+    bool checkWc(const KURL&url);
     bool getLogMsg(QString&);
 protected:
     QString getDefaultLog();
 };
+
+}
+
 #endif
