@@ -19,6 +19,7 @@
  ***************************************************************************/
 #include "logmsg_impl.h"
 #include "src/settings/kdesvnsettings.h"
+#include "depthselector.h"
 
 #include <ktextedit.h>
 #include <kcombobox.h>
@@ -29,6 +30,11 @@
 #include <kapp.h>
 #include <kconfigbase.h>
 #include <kconfig.h>
+#include <kurlrequesterdlg.h>
+#include <kio/netaccess.h>
+#include <kmessagebox.h>
+#include <kfile.h>
+#include <kurlrequester.h>
 
 #include <qvbox.h>
 #include <qcheckbox.h>
@@ -37,10 +43,12 @@
 #include <qlayout.h>
 #include <qwidget.h>
 #include <qpushbutton.h>
+#include <qfile.h>
 
 #define MAX_MESSAGE_HISTORY 10
 
 QValueList<QString> Logmsg_impl::sLogHistory = QValueList<QString>();
+QString Logmsg_impl::sLastMessage=QString();
 const QString Logmsg_impl::groupName("logmsg_dlg_size");
 
 unsigned int Logmsg_impl::smax_message_history = 0xFFFF;
@@ -192,9 +200,9 @@ QString Logmsg_impl::getMessage()const
 /*!
     \fn Logmsg_impl::isRecursive()const
  */
-bool Logmsg_impl::isRecursive()const
+svn::Depth Logmsg_impl::getDepth()const
 {
-    return m_RecursiveButton->isChecked();
+    return m_DepthSelector->getDepth();
 }
 
 /*!
@@ -237,34 +245,43 @@ void Logmsg_impl::initHistory()
             m_LogHistory->insertItem((*it).left(37)+"...");
         }
     }
+    if (sLastMessage.length()>0) {
+        m_LogEdit->setText(sLastMessage);
+        sLastMessage=QString();
+    }
 }
 
 
 /*!
     \fn Logmsg_impl::saveHistory()
  */
-void Logmsg_impl::saveHistory()
+void Logmsg_impl::saveHistory(bool canceld)
 {
-    if (m_LogEdit->text().length()==0) return;
+    if (m_LogEdit->text().length()==0||m_LogEdit->text().length()>512) return;
     /// @todo make static threadsafe
-    QValueList<QString>::iterator it;
-    if ( (it=sLogHistory.find(m_LogEdit->text()))!=sLogHistory.end()) {
-        sLogHistory.erase(it);
+    if (!canceld) {
+        QValueList<QString>::iterator it;
+        if ( (it=sLogHistory.find(m_LogEdit->text()))!=sLogHistory.end()) {
+            sLogHistory.erase(it);
+        }
+        sLogHistory.push_front(m_LogEdit->text());
+        if (sLogHistory.size()>smax_message_history) {
+            sLogHistory.erase(sLogHistory.fromLast());
+        }
+        KConfigGroup cs(Kdesvnsettings::self()->config(),"log_messages");
+        for (unsigned int i = 0; i < sLogHistory.size();++i) {
+            cs.writeEntry(QString("log_%0").arg(i),sLogHistory[i]);
+        }
+        cs.sync();
+    } else {
+        sLastMessage=m_LogEdit->text();
     }
-    sLogHistory.push_front(m_LogEdit->text());
-    if (sLogHistory.size()>smax_message_history) {
-        sLogHistory.erase(sLogHistory.fromLast());
-    }
-    KConfigGroup cs(Kdesvnsettings::self()->config(),"log_messages");
-    for (unsigned int i = 0; i < sLogHistory.size();++i) {
-        cs.writeEntry(QString("log_%0").arg(i),sLogHistory[i]);
-    }
-    cs.sync();
 }
 
-QString Logmsg_impl::getLogmessage(bool*ok,bool*rec,bool*keep_locks,QWidget*parent,const char*name)
+QString Logmsg_impl::getLogmessage(bool*ok,svn::Depth*rec,bool*keep_locks,QWidget*parent,const char*name)
 {
-    bool _ok,_rec,_keep_locks;
+    bool _ok,_keep_locks;
+    svn::Depth _depth = svn::DepthUnknown;
     QString msg("");
 
     Logmsg_impl*ptr=0;
@@ -275,7 +292,7 @@ QString Logmsg_impl::getLogmessage(bool*ok,bool*rec,bool*keep_locks,QWidget*pare
 
     ptr = new Logmsg_impl(Dialog1Layout);
     if (!rec) {
-        ptr->m_RecursiveButton->hide();
+        ptr->m_DepthSelector->hide();
     }
     if (!keep_locks) {
         ptr->m_keepLocksButton->hide();
@@ -285,24 +302,25 @@ QString Logmsg_impl::getLogmessage(bool*ok,bool*rec,bool*keep_locks,QWidget*pare
     if (dlg.exec()!=QDialog::Accepted) {
         _ok = false;
         /* avoid compiler warnings */
-        _rec = false;
         _keep_locks = false;
     } else {
         _ok = true;
-        _rec = ptr->isRecursive();
+        _depth = ptr->getDepth();
         _keep_locks = ptr->isKeeplocks();
         msg=ptr->getMessage();
-        ptr->saveHistory();
     }
+    ptr->saveHistory(!_ok);
+
     dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),groupName,false);
     if (ok) *ok = _ok;
-    if (rec) *rec = _rec;
+    if (rec) *rec = _depth;
     return msg;
 }
 
-QString Logmsg_impl::getLogmessage(const svn::CommitItemList&items,bool*ok,bool*rec,bool*keep_locks,QWidget*parent,const char*name)
+QString Logmsg_impl::getLogmessage(const svn::CommitItemList&items,bool*ok,svn::Depth*rec,bool*keep_locks,QWidget*parent,const char*name)
 {
-    bool _ok,_rec,_keep_locks;
+    bool _ok,_keep_locks;
+    svn::Depth _depth = svn::DepthUnknown;
     QString msg("");
 
     Logmsg_impl*ptr=0;
@@ -313,7 +331,7 @@ QString Logmsg_impl::getLogmessage(const svn::CommitItemList&items,bool*ok,bool*
 
     ptr = new Logmsg_impl(items,Dialog1Layout);
     if (!rec) {
-        ptr->m_RecursiveButton->hide();
+        ptr->m_DepthSelector->hide();
     }
     if (!keep_locks) {
         ptr->m_keepLocksButton->hide();
@@ -324,26 +342,27 @@ QString Logmsg_impl::getLogmessage(const svn::CommitItemList&items,bool*ok,bool*
     if (dlg.exec()!=QDialog::Accepted) {
         _ok = false;
         /* avoid compiler warnings */
-        _rec = false;
         _keep_locks = false;
     } else {
         _ok = true;
-        _rec = ptr->isRecursive();
+        _depth = ptr->getDepth();
         _keep_locks = ptr->isKeeplocks();
         msg=ptr->getMessage();
-        ptr->saveHistory();
     }
+    ptr->saveHistory(!_ok);
+
     dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),groupName,false);
     if (ok) *ok = _ok;
-    if (rec) *rec = _rec;
+    if (rec) *rec = _depth;
     if (keep_locks) *keep_locks = _keep_locks;
     return msg;
 }
 
 QString Logmsg_impl::getLogmessage(const QMap<QString,QString>&items,
-    bool*ok,bool*rec,bool*keep_locks,QWidget*parent,const char*name)
+    bool*ok,svn::Depth*rec,bool*keep_locks,QWidget*parent,const char*name)
 {
     bool _ok,_rec,_keep_locks;
+    svn::Depth _depth = svn::DepthUnknown;
     QString msg("");
 
     Logmsg_impl*ptr=0;
@@ -354,7 +373,7 @@ QString Logmsg_impl::getLogmessage(const QMap<QString,QString>&items,
 
     ptr = new Logmsg_impl(items,Dialog1Layout);
     if (!rec) {
-        ptr->m_RecursiveButton->hide();
+        ptr->m_DepthSelector->hide();
     }
     if (!keep_locks) {
         ptr->m_keepLocksButton->hide();
@@ -368,14 +387,15 @@ QString Logmsg_impl::getLogmessage(const QMap<QString,QString>&items,
         _keep_locks=false;
     } else {
         _ok = true;
-        _rec = ptr->isRecursive();
+        _depth = ptr->getDepth();
         msg=ptr->getMessage();
-        ptr->saveHistory();
         _keep_locks = ptr->isKeeplocks();
     }
+    ptr->saveHistory(!_ok);
+
     dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),groupName,false);
     if (ok) *ok = _ok;
-    if (rec) *rec = _rec;
+    if (rec) *rec = _depth;
     if (keep_locks) *keep_locks = _keep_locks;
     return msg;
 }
@@ -395,7 +415,7 @@ QString Logmsg_impl::getLogmessage(const logActionEntries&_on,
             KDialogBase::Ok,true);
     QWidget* Dialog1Layout = dlg.makeVBoxMainWidget();
     ptr = new Logmsg_impl(_on,_off,Dialog1Layout);
-    ptr->m_RecursiveButton->hide();
+    ptr->m_DepthSelector->hide();
     if (!keep_locks) {
         ptr->m_keepLocksButton->hide();
     }
@@ -413,9 +433,9 @@ QString Logmsg_impl::getLogmessage(const logActionEntries&_on,
     } else {
         _ok = true;
         msg=ptr->getMessage();
-        ptr->saveHistory();
         _keep_locks = ptr->isKeeplocks();
     }
+    ptr->saveHistory(!_ok);
     dlg.saveDialogSize(*(Kdesvnsettings::self()->config()),groupName,false);
     if (ok) *ok = _ok;
     _result = ptr->selectedEntries();
@@ -426,10 +446,14 @@ QString Logmsg_impl::getLogmessage(const logActionEntries&_on,
 /*!
     \fn Logmsg_impl::setRecCheckboxtext(const QString&what)
  */
-void Logmsg_impl::setRecCheckboxtext(const QString&what,bool checked)
+void Logmsg_impl::addItemWidget(QWidget*aWidget)
 {
-    m_RecursiveButton->setText(what);
-    m_RecursiveButton->setChecked(checked);
+    m_DepthSelector->addItemWidget(aWidget);
+/*    aWidget->reparent(this,geometry().topLeft());
+    m_ItemsLayout->addWidget(aWidget);
+    kdDebug()<<"SizeHint: "<<aWidget->minimumSizeHint()<< endl;
+    aWidget->setSizePolicy(QSizePolicy::Fixed,QSizePolicy::Fixed);
+    setMinimumHeight(minimumSizeHint().height());*/
 }
 
 Logmsg_impl::logActionEntries Logmsg_impl::selectedEntries()
@@ -575,4 +599,55 @@ void Logmsg_impl::hideNewItems(bool how)
     }
 }
 
+/*!
+    \fn Logmsg_impl::hideDepth(bool hide)
+ */
+void Logmsg_impl::hideDepth(bool ahide)
+{
+    m_DepthSelector->hideDepth(ahide);
+//    if (hide) m_DepthSelector->hide();
+//    else m_DepthSelector->show();
+}
+
+void Logmsg_impl::insertFile(const QString&fname)
+{
+    QFile ifs(fname);
+    if (ifs.open(IO_ReadOnly)) {
+        QTextStream ts(&ifs);
+        QString _content = ts.read();
+        int para,index;
+        m_LogEdit->getCursorPosition(&para,&index);
+        m_LogEdit->insertAt(_content,para,index);
+    }
+}
+
+void Logmsg_impl::insertFile()
+{
+    QString head = i18n("Select textfile for insert");
+    KURLRequesterDlg dlg(QString::null,this,head);
+    dlg.setCaption(head);
+    KFile::Mode mode = static_cast<KFile::Mode>(KFile::File);
+    dlg.urlRequester()->setMode(mode);
+    dlg.urlRequester()->setCaption(head);
+
+    if (dlg.exec()!=QDialog::Accepted) {
+        return;
+    }
+    KURL _url = dlg.selectedURL();
+    if (_url.isEmpty() || !_url.isValid()) {
+        return;
+    }
+    if (_url.isLocalFile()) {
+        insertFile(_url.path());
+    } else {
+        QString tmpFile;
+        if( KIO::NetAccess::download(_url, tmpFile, this) ) {
+            insertFile( tmpFile );
+            KIO::NetAccess::removeTempFile( tmpFile );
+        } else {
+            KMessageBox::error(this, KIO::NetAccess::lastErrorString() );
+        }
+    }
+}
+
 #include "logmsg_impl.moc"
