@@ -20,11 +20,15 @@
 #include "revisiontree.h"
 #include "../stopdlg.h"
 #include "src/svnqt/log_entry.hpp"
+#include "src/svnqt/cache/LogCache.hpp"
+#include "src/svnqt/cache/ReposLog.hpp"
+#include "src/svnqt/url.hpp"
 #include "helpers/sub2qt.h"
 #include "revtreewidget.h"
 #include "revgraphview.h"
 #include "elogentry.h"
 #include "src/svnfrontend/fronthelpers/cursorstack.h"
+#include "src/settings/kdesvnsettings.h"
 
 #include <kdebug.h>
 #include <kprogress.h>
@@ -64,7 +68,7 @@ public:
     svn::Client*m_Client;
     QObject* m_Listener;
 
-    bool getLogs(const QString&,const svn::Revision&startr,const svn::Revision&endr);
+    bool getLogs(const QString&,const svn::Revision&startr,const svn::Revision&endr,const QString&origin);
 };
 
 RtreeData::RtreeData()
@@ -82,7 +86,7 @@ RtreeData::~RtreeData()
     delete progress;
 }
 
-bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const svn::Revision&endr)
+bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const svn::Revision&endr,const QString&origin)
 {
     if (!m_Listener||!m_Client) {
         return false;
@@ -91,8 +95,20 @@ bool RtreeData::getLogs(const QString&reposRoot,const svn::Revision&startr,const
         CursorStack a(Qt::BusyCursor);
         StopDlg sdlg(m_Listener,dlgParent,
                      0,"Logs",i18n("Getting logs - hit cancel for abort"));
-        m_Client->log(reposRoot,endr,startr,m_OldHistory,true,false,0);
-    } catch (svn::ClientException ce) {
+        if (svn::Url::isLocal(reposRoot) ) {
+            m_Client->log(reposRoot,endr,startr,m_OldHistory,startr,true,false,0);
+        } else {
+            svn::cache::ReposLog rl(m_Client,reposRoot);
+            if (rl.isValid()) {
+                rl.simpleLog(m_OldHistory,startr,endr,!Kdesvnsettings::network_on());
+            } else if (Kdesvnsettings::network_on()) {
+                m_Client->log(reposRoot,endr,startr,m_OldHistory,startr,true,false,0);
+            } else {
+                KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1").arg(i18n("No logcache possible due broken database and networking not allowed.")));
+                return false;
+            }
+        }
+    } catch (const svn::Exception&ce) {
         kdDebug()<<ce.msg() << endl;
         KMessageBox::error(0,i18n("Could not retrieve logs, reason:\n%1").arg(ce.msg()));
         return false;
@@ -114,7 +130,7 @@ RevisionTree::RevisionTree(svn::Client*aClient,
     m_Data->m_Listener=aListener;
     m_Data->dlgParent=parent;
 
-    if (!m_Data->getLogs(reposRoot,startr,endr)) {
+    if (!m_Data->getLogs(reposRoot,startr,endr,origin)) {
         return;
     }
 
