@@ -64,13 +64,11 @@ public:
     virtual void SelectionList(SvnItemList*target);
 
     virtual QWidget*realWidget();
-    const svn::Status&maindir()const{return m_mainEntry;}
 
     KActionCollection*filesActions();
     bool refreshItem(FileListViewItem*);
 
 protected:
-    svn::Status m_mainEntry;
     const svn::Revision& remoteRevision()const;
     bool m_deletePerfect;
     QMap<QString,bool> m_Dirsread;
@@ -92,7 +90,6 @@ protected:
     void setupActions();
     svn::Client*svnclient();
 
-    void enableActions();
 
     FileListViewItem* singleSelected();
     FileListViewItemList* allSelected();
@@ -179,6 +176,9 @@ protected slots:
 
     /* internal slots */
     virtual void readSupportData();
+    virtual void slotUpdateLogCache();
+
+    virtual void enableActions();
 
 signals:
     void sigLogMessage(const QString&);
@@ -189,6 +189,7 @@ signals:
     void sigUrlChanged(const QString&);
     void sigProplist(const svn::PathPropertiesMapListPtr&,bool,const QString&);
     void sigListError();
+    void sigCacheStatus(Q_LONG,Q_LONG);
 
 public slots:
     virtual void refreshCurrentTree();
