@@ -41,10 +41,16 @@ ThreadContextListener::~ThreadContextListener()
     delete m_Data;
 }
 
+QMutex*ThreadContextListener::callbackMutex()
+{
+    static QMutex s_CallbackMutex;
+    return &s_CallbackMutex;
+}
+
 bool ThreadContextListener::contextGetLogin(const QString& realm, QString& username, QString& password, bool& maySave)
 {
-    kdDebug()<<"Getting threaded login"<<endl;
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
+    m_WaitMutex.lock();
     ThreadContextListenerData::slogin_data _data;
     _data.realm=realm;
     _data.user=username;
@@ -55,9 +61,9 @@ bool ThreadContextListener::contextGetLogin(const QString& realm, QString& usern
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_LOGIN_PROMPT);
     void*t = (void*)&_data;
     ev->setData(t);
-    kdDebug()<<"Post event "<<EVENT_THREAD_LOGIN_PROMPT<<" (login) from thread " << endl;
     kapp->postEvent(this,ev);
-    m_Data->m_trustpromptWait.wait();
+    m_Data->m_trustpromptWait.wait(&m_WaitMutex);
+    m_WaitMutex.unlock();
     username = _data.user;
     password = _data.password;
     maySave = _data.maysave;
@@ -66,9 +72,8 @@ bool ThreadContextListener::contextGetLogin(const QString& realm, QString& usern
 
 bool ThreadContextListener::contextGetSavedLogin(const QString & realm,QString & username,QString & password)
 {
-
-    kdDebug()<<"Getting threaded saved login"<<endl;
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
+    m_WaitMutex.lock();
     ThreadContextListenerData::slogin_data _data;
     _data.realm=realm;
     _data.user=username;
@@ -79,9 +84,9 @@ bool ThreadContextListener::contextGetSavedLogin(const QString & realm,QString &
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_LOGIN_SAVED);
     void*t = (void*)&_data;
     ev->setData(t);
-    kdDebug()<<"Post event "<<EVENT_THREAD_LOGIN_SAVED<<" (login saved) from thread " << endl;
     kapp->postEvent(this,ev);
-    m_Data->m_trustpromptWait.wait();
+    m_Data->m_trustpromptWait.wait(&m_WaitMutex);
+    m_WaitMutex.unlock();
     username = _data.user;
     password = _data.password;
     return _data.ok;
@@ -89,7 +94,8 @@ bool ThreadContextListener::contextGetSavedLogin(const QString & realm,QString &
 
 bool ThreadContextListener::contextGetLogMessage(QString& msg,const svn::CommitItemList&_items)
 {
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
+    m_WaitMutex.lock();
     ThreadContextListenerData::slog_message log;
     log.ok = false;
     log.msg = "";
@@ -97,31 +103,34 @@ bool ThreadContextListener::contextGetLogMessage(QString& msg,const svn::CommitI
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_LOGMSG_PROMPT);
     void*t = (void*)&log;
     ev->setData(t);
-    kdDebug()<<"Post event "<<EVENT_THREAD_LOGMSG_PROMPT<<" from thread " << endl;
     kapp->postEvent(this,ev);
-    m_Data->m_trustpromptWait.wait();
+    m_Data->m_trustpromptWait.wait(&m_WaitMutex);
+    m_WaitMutex.unlock();
     msg = log.msg;
     return log.ok;
 }
 
 bool ThreadContextListener::contextSslClientCertPrompt(QString& certFile)
 {
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
+    m_WaitMutex.lock();
+
     ThreadContextListenerData::scert_file scertf;
     scertf.ok = false;
     scertf.certfile="";
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_CERT_SELECT_PROMPT);
     ev->setData((void*)&scertf);
-    kdDebug()<<"Post event "<<EVENT_THREAD_CERT_SELECT_PROMPT<<" from thread " << endl;
     kapp->postEvent(this,ev);
-    m_Data->m_trustpromptWait.wait();
+    m_Data->m_trustpromptWait.wait(&m_WaitMutex);
+    m_WaitMutex.unlock();
     certFile = scertf.certfile;
     return scertf.ok;
 }
 
 bool ThreadContextListener::contextSslClientCertPwPrompt(QString& password, const QString& realm, bool& maySave)
 {
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
+    m_WaitMutex.lock();
     ThreadContextListenerData::scert_pw scert_data;
     scert_data.ok=false;
     scert_data.maysave=false;
@@ -129,9 +138,9 @@ bool ThreadContextListener::contextSslClientCertPwPrompt(QString& password, cons
     scert_data.realm=realm;
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_CERT_PW_PROMPT);
     ev->setData((void*)&scert_data);
-    kdDebug()<<"Post event "<<EVENT_THREAD_CERT_PW_PROMPT<<" from thread " << endl;
     kapp->postEvent(this,ev);
-    m_Data->m_trustpromptWait.wait();
+    m_Data->m_trustpromptWait.wait(&m_WaitMutex);
+    m_WaitMutex.unlock();
     password = scert_data.password;
     maySave = scert_data.maysave;
     return scert_data.ok;
@@ -139,21 +148,22 @@ bool ThreadContextListener::contextSslClientCertPwPrompt(QString& password, cons
 
 svn::ContextListener::SslServerTrustAnswer ThreadContextListener::contextSslServerTrustPrompt(const SslServerTrustData& data, apr_uint32_t&/* acceptedFailures*/)
 {
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
+    m_WaitMutex.lock();
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_SSL_TRUST_PROMPT);
     ThreadContextListenerData::strust_answer trust_answer;
     trust_answer.m_SslTrustAnswer=DONT_ACCEPT;
     trust_answer.m_Trustdata = &data;
     ev->setData((void*)&trust_answer);
-    kdDebug()<<"Post event "<<EVENT_THREAD_SSL_TRUST_PROMPT<<" from thread " << endl;
     kapp->postEvent(this,ev);
-    m_Data->m_trustpromptWait.wait();
+    m_Data->m_trustpromptWait.wait(&m_WaitMutex);
+    m_WaitMutex.unlock();
     return trust_answer.m_SslTrustAnswer;
 }
 
 void ThreadContextListener::contextNotify(const QString&aMsg)
 {
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_NOTIFY);
     // receiver must delete data!
     ThreadContextListenerData::snotify* _notify = new ThreadContextListenerData::snotify();
@@ -170,7 +180,7 @@ void ThreadContextListener::contextProgress(long long int current, long long int
     if (m_Data->noProgress||current==0) {
         return;
     }
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_NOTIFY);
     // receiver must delete data!
     ThreadContextListenerData::snotify* _notify = new ThreadContextListenerData::snotify();
@@ -189,7 +199,7 @@ void ThreadContextListener::contextProgress(long long int current, long long int
 
 void ThreadContextListener::sendTick()
 {
-    QMutexLocker lock(&(m_Data->m_CallbackMutex));
+    QMutexLocker lock(callbackMutex());
     QCustomEvent*ev = new QCustomEvent(EVENT_THREAD_NOTIFY);
     // receiver must delete data!
     ThreadContextListenerData::snotify* _notify = new ThreadContextListenerData::snotify();
@@ -201,6 +211,7 @@ void ThreadContextListener::sendTick()
 /* methods below may only called from mainthread! (via event) */
 void ThreadContextListener::event_contextGetLogin(void*data)
 {
+    QMutexLocker lock(&m_WaitMutex);
     if (!data) {
         m_Data->m_trustpromptWait.wakeAll();
         return;
@@ -208,12 +219,12 @@ void ThreadContextListener::event_contextGetLogin(void*data)
     ThreadContextListenerData::slogin_data*_data = (ThreadContextListenerData::slogin_data*)data;
 
     _data->ok = CContextListener::contextGetLogin(_data->realm, _data->user, _data->password, _data->maysave);
-    //_data->ok = CContextListener::contextGetSavedLogin(_data->realm, _data->user, _data->password);
     m_Data->m_trustpromptWait.wakeAll();
 }
 
 void ThreadContextListener::event_contextGetSavedLogin(void*data)
 {
+    QMutexLocker lock(&m_WaitMutex);
     if (!data) {
         m_Data->m_trustpromptWait.wakeAll();
         return;
@@ -225,6 +236,7 @@ void ThreadContextListener::event_contextGetSavedLogin(void*data)
 
 void ThreadContextListener::event_contextGetLogMessage(void * data)
 {
+    QMutexLocker lock(&m_WaitMutex);
     if (!data) {
         m_Data->m_trustpromptWait.wakeAll();
         return;
@@ -237,6 +249,7 @@ void ThreadContextListener::event_contextGetLogMessage(void * data)
 
 void ThreadContextListener::event_contextSslClientCertPrompt(void*data)
 {
+    QMutexLocker lock(&m_WaitMutex);
     if (!data) {
         m_Data->m_trustpromptWait.wakeAll();
         return;
@@ -248,6 +261,7 @@ void ThreadContextListener::event_contextSslClientCertPrompt(void*data)
 
 void ThreadContextListener::event_contextSslClientCertPwPrompt(void*data)
 {
+    QMutexLocker lock(&m_WaitMutex);
     if (!data) {
         m_Data->m_trustpromptWait.wakeAll();
         return;
@@ -259,6 +273,7 @@ void ThreadContextListener::event_contextSslClientCertPwPrompt(void*data)
 
 void ThreadContextListener::event_contextSslServerTrustPrompt(void*data)
 {
+    QMutexLocker lock(&m_WaitMutex);
     /*
      * m_SslTrustAnswer is made threadsafe due the m_trustpromptWait - the calling thread waits until wakeAll is called!
      */
