@@ -37,9 +37,9 @@ class ThreadContextListener : public CContextListener
 {
     Q_OBJECT
 public:
-    ThreadContextListener(QObject* parent, const char* name);
+    ThreadContextListener(QObject* parent, const char* name=0);
 
-    ~ThreadContextListener();
+    virtual ~ThreadContextListener();
 
     virtual bool contextGetLogin(const QString& realm, QString& username, QString& password, bool& maySave);
     virtual bool contextGetSavedLogin(const QString & realm,QString & username,QString & password);
@@ -52,6 +52,8 @@ public:
     virtual void sendTick();
     virtual void contextProgress(long long int current, long long int max);
 
+    static QMutex*callbackMutex();
+
 protected:
     virtual void event_contextGetLogin(void*_data);
     virtual void event_contextGetSavedLogin(void*_data);
@@ -63,8 +65,8 @@ protected:
     virtual void customEvent(QCustomEvent*);
 
     /* stores all internals */
+    QMutex m_WaitMutex;
     ThreadContextListenerData*m_Data;
 };
 
-
 #endif
