@@ -27,7 +27,7 @@
  * history and logs, available at http://rapidsvn.tigris.org/.
  * ====================================================================
  */
-#if defined( _MSC_VER) && _MSC_VER <= 1200
+#if defined( _MSC_VER) && _MSC_VER <= 1550
 #pragma warning( disable: 4786 )// debug symbol truncated
 #endif
 
@@ -60,9 +60,18 @@ namespace svn
         };
 
         SvnInit::SvnInit() {
-            apr_pool_initialize();
             svn_cmdline_init("svnqt",0);
             qDebug("svn_cmdline_init done");
+            QString BasePath=QDir::HOMEDIR();
+            QDir d;
+            if (!d.exists(BasePath)) {
+                d.mkdir(BasePath);
+            }
+            BasePath=BasePath+"/"+".svnqt";
+            if (!d.exists(BasePath)) {
+                d.mkdir(BasePath);
+            }
+
         }
     }
 
