@@ -45,6 +45,8 @@
 #include "svnqt/exception.hpp"
 #include "svnqt/svnqt_defines.hpp"
 
+#include "svnqt/helper.hpp"
+
 static int
 compare_items_as_paths (const svn_sort__item_t *a, const svn_sort__item_t *b)
 {
@@ -112,7 +114,6 @@ namespace svn
     Pool pool;
 
     apr_hash_t * hash;
-#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
     apr_hash_t * lock_hash;
 
     svn_error_t * error =
@@ -124,20 +125,6 @@ namespace svn
                      recurse,
                      *m_context,
                      pool);
-#else
-    QString url = pathOrUrl;
-    url+=QString::FROMUTF8("/");
-    bool _det = true;
-
-    svn_error_t * error =
-      svn_client_ls2 (&hash,
-                     pathOrUrl.cstr(),
-                     peg,
-                     revision,
-                     recurse,
-                     *m_context,
-                     pool);
-#endif
 
     if (error != 0)
       throw ClientException (error);
@@ -152,9 +139,7 @@ namespace svn
     {
       const char *entryname;
       svn_dirent_t *dirent;
-#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
       svn_lock_t * lockent;
-#endif
       svn_sort__item_t *item;
 
       item = &APR_ARRAY_IDX (array, i, svn_sort__item_t);
@@ -163,32 +148,19 @@ namespace svn
 
       dirent = static_cast<svn_dirent_t *>
         (apr_hash_get (hash, entryname, item->klen));
-#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
       lockent = static_cast<svn_lock_t *>
         (apr_hash_get(lock_hash,entryname,item->klen));
       entries.push_back (new DirEntry(QString::FROMUTF8(entryname), dirent,lockent));
-#else
-      if (!_det) {
-        entries.push_back (new DirEntry(QString::FROMUTF8(entryname),dirent));
-      } else {
-        try {
-            InfoEntries infoEntries = info(url+entryname,false,revision,Revision(Revision::UNDEFINED));
-            entries.push_back(DirEntry(QString::FROMUTF8(entryname),dirent,infoEntries[0].lockEntry()));
-        } catch (ClientException) {
-            _det = false;
-            entries.push_back(new DirEntry(QString::FROMUTF8(entryname),dirent));
-        }
-      }
-#endif
     }
 
     return entries;
   }
 
-#if (SVN_VER_MAJOR>=1) && (SVN_VER_MINOR>=4)
+#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 4)) || (SVN_VER_MAJOR > 1)
   static svn_error_t * s_list_func
           (void * baton,const char*path,const svn_dirent_t*dirent,const svn_lock_t*lock,const char* abs_path,apr_pool_t*)
   {
+      Q_UNUSED(abs_path);
       if (!baton || !path || !dirent) {
           return 0;
       }
@@ -209,14 +181,29 @@ namespace svn
   Client_impl::list(const Path& pathOrUrl,
                 const Revision& revision,
                 const Revision& peg,
-                bool recurse,bool retrieve_locks) throw (ClientException)
+                Depth depth,bool retrieve_locks) throw (ClientException)
   {
-#if (SVN_VER_MAJOR>=1) && (SVN_VER_MINOR>=4)
+
+#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 4)) || (SVN_VER_MAJOR > 1)
       sBaton _baton;
       Pool pool;
       DirEntries entries;
       _baton.m_data = &entries;
       _baton.m_context=m_context;
+#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+      svn_error_t * error = svn_client_list2(pathOrUrl.cstr(),
+                                            peg,
+                                            revision,
+                                            svn::internal::DepthToSvn(depth),
+                                            SVN_DIRENT_ALL,
+                                            retrieve_locks,
+                                            s_list_func,
+                                            &_baton,
+                                            *m_context,
+                                            pool
+                                           );
+#else
+      bool recurse = depth==DepthInfinity;
       svn_error_t * error = svn_client_list(pathOrUrl.cstr(),
                                             peg,
                                             revision,
@@ -228,15 +215,16 @@ namespace svn
                                             *m_context,
                                             pool
                                            );
+#endif
       if (error != 0) {
           throw ClientException (error);
       }
       return entries;
 #else
       if (!retrieve_locks) {
-          return list_simple(pathOrUrl,revision,peg,recurse);
+          return list_simple(pathOrUrl,revision,peg,depth==DepthInfinity);
       } else {
-          return list_locks(pathOrUrl,revision,peg,recurse);
+          return list_locks(pathOrUrl,revision,peg,depth==DepthInfinity);
       }
 #endif
   }
