@@ -21,8 +21,11 @@
 
 #include "contextdata.hpp"
 #include "context_listener.hpp"
+#include "conflictresult.hpp"
+#include "conflictdescription.hpp"
 
 #include <svn_config.h>
+#include <svn_wc.h>
 
 namespace svn {
 
@@ -42,6 +45,7 @@ ContextData::ContextData(const QString & configDir_)
       // intialize authentication providers
       // * simple
       // * username
+      // * simple pw cache of frontend app
       // * simple pw storage
       // * simple prompt
       // * ssl server trust file
@@ -51,10 +55,14 @@ ContextData::ContextData(const QString & configDir_)
       // * ssl client cert pw prompt
       // * ssl client cert file
       // ===================
-      // 10 providers
+      // 11 providers (+1 for windowsvariant)
 
     apr_array_header_t *providers =
+#if defined(WIN32) && (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 4)
+        apr_array_make (pool, 12, sizeof (svn_auth_provider_object_t *));
+#else
         apr_array_make (pool, 11, sizeof (svn_auth_provider_object_t *));
+#endif
     svn_auth_provider_object_t *provider;
 
 #if defined(WIN32) && (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 4)
@@ -83,7 +91,15 @@ ContextData::ContextData(const QString & configDir_)
 #else
     svn_client_get_simple_prompt_provider
 #endif
-    (&provider,onFirstPrompt,this,0,pool);
+    (&provider,onCachedPrompt,this,0,pool);
+    *(svn_auth_provider_object_t **)apr_array_push (providers) = provider;
+
+#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 4)
+    svn_auth_get_simple_prompt_provider
+#else
+    svn_client_get_simple_prompt_provider
+#endif
+    (&provider,onSavedPrompt,this,0,pool);
     *(svn_auth_provider_object_t **)apr_array_push (providers) = provider;
 
 #if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 4)
@@ -173,12 +189,22 @@ ContextData::ContextData(const QString & configDir_)
 
       m_ctx->log_msg_func = onLogMsg;
       m_ctx->log_msg_baton = this;
-#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
+      // subversion 1.3 functions
       m_ctx->log_msg_func2 = onLogMsg2;
       m_ctx->log_msg_baton2 = this;
 
       m_ctx->progress_func = onProgress;
       m_ctx->progress_baton = this;
+
+#if  ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5) || (SVN_VER_MAJOR > 2))
+      m_ctx->log_msg_func3 = onLogMsg3;
+      m_ctx->log_msg_baton3 = this;
+
+      m_ctx->conflict_func = onWcConflictResolver;
+      m_ctx->conflict_baton = this;
+
+      m_ctx->client_name = "SvnQt wrapper client";
+      initMimeTypes();
 #endif
 }
 
@@ -276,6 +302,21 @@ bool ContextData::retrieveSavedLogin (const char * username_,
     return ok;
 }
 
+bool ContextData::retrieveCachedLogin (const char * username_,
+                                 const char * realm,
+                                 bool & may_save)
+{
+    bool ok;
+    may_save = false;
+
+    if (listener == 0)
+        return false;
+
+    username = QString::FROMUTF8(username_);
+    ok = listener->contextGetCachedLogin(QString::FROMUTF8(realm),username, password);
+    return ok;
+}
+
 svn_client_ctx_t *ContextData::ctx()
 {
     return m_ctx;
@@ -389,6 +430,37 @@ svn_error_t *ContextData::onLogMsg2 (const char **log_msg,
     return SVN_NO_ERROR;
 }
 
+#if  ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5) || (SVN_VER_MAJOR > 2))
+svn_error_t *ContextData::onLogMsg3 (const char **log_msg,
+              const char **tmp_file,
+              const apr_array_header_t * commit_items,
+              void *baton,
+              apr_pool_t * pool)
+{
+    ContextData * data = 0;
+    SVN_ERR (getContextData (baton, &data));
+
+    QString msg;
+    if (data->logIsSet) {
+        msg = data->getLogMessage ();
+    } else {
+        CommitItemList _items;
+        for (int j = 0; j < commit_items->nelts; ++j) {
+            svn_client_commit_item3_t*item = ((svn_client_commit_item3_t **)commit_items->elts)[j];
+            _items.push_back(CommitItem(item));
+        }
+
+        if (!data->retrieveLogMessage (msg,_items)) {
+            return data->generate_cancel_error();
+        }
+    }
+
+    *log_msg = apr_pstrdup (pool,msg.TOUTF8());
+    *tmp_file = NULL;
+    return SVN_NO_ERROR;
+}
+#endif
+
 void ContextData::onNotify (void * baton,
               const char *path,
               svn_wc_notify_action_t action,
@@ -422,7 +494,34 @@ svn_error_t * ContextData::onCancel (void * baton)
         return SVN_NO_ERROR;
 }
 
-svn_error_t *ContextData::onFirstPrompt(svn_auth_cred_simple_t **cred,
+svn_error_t *ContextData::onCachedPrompt(svn_auth_cred_simple_t **cred,
+                                            void *baton,
+                                            const char *realm,
+                                            const char *username,
+                                            svn_boolean_t _may_save,
+                                            apr_pool_t *pool)
+{
+    ContextData * data = 0;
+    SVN_ERR (getContextData (baton, &data));
+    bool may_save = _may_save != 0;
+    if (!data->retrieveCachedLogin (username, realm, may_save ))
+        return SVN_NO_ERROR;
+    svn_auth_cred_simple_t* lcred = (svn_auth_cred_simple_t*)
+            apr_palloc (pool, sizeof (svn_auth_cred_simple_t));
+    QByteArray l;
+    l = data->getPassword().TOUTF8();
+    lcred->password = apr_pstrndup (pool,l,l.size());
+    l = data->getUsername().TOUTF8();
+    lcred->username = apr_pstrndup (pool,l,l.size());
+
+      // tell svn if the credentials need to be saved
+    lcred->may_save = may_save;
+    *cred = lcred;
+
+    return SVN_NO_ERROR;
+}
+
+svn_error_t *ContextData::onSavedPrompt(svn_auth_cred_simple_t **cred,
                                             void *baton,
                                             const char *realm,
                                             const char *username,
@@ -628,4 +727,56 @@ void ContextData::onProgress(apr_off_t progress, apr_off_t total, void*baton, ap
     data->getListener()->contextProgress(progress,total);
 }
 
+#if  ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5) || (SVN_VER_MAJOR > 2))
+void ContextData::initMimeTypes()
+{
+    // code take from subversion 1.5 commandline client
+    const char *mimetypes_file;
+    svn_error_t * err = 0L;
+    svn_config_t * cfg = (svn_config_t *)apr_hash_get(m_ctx->config, SVN_CONFIG_CATEGORY_CONFIG,
+                       APR_HASH_KEY_STRING);
+
+    svn_config_get(cfg, &mimetypes_file,
+                   SVN_CONFIG_SECTION_MISCELLANY,
+                   SVN_CONFIG_OPTION_MIMETYPES_FILE, false);
+    if (mimetypes_file && *mimetypes_file) {
+        if ((err = svn_io_parse_mimetypes_file(&(m_ctx->mimetypes_map),
+             mimetypes_file, pool))) {
+                 svn_handle_error2(err, stderr, false, "svn: ");
+        }
+    }
+}
+#endif
+
+svn_error_t* ContextData::onWcConflictResolver(svn_wc_conflict_result_t**result,const svn_wc_conflict_description_t *description, void *baton, apr_pool_t *pool)
+{
+#if  ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5) || (SVN_VER_MAJOR > 2))
+    ContextData * data = 0;
+    SVN_ERR (getContextData (baton, &data));
+    ConflictResult cresult;
+    if (!data->getListener()->contextConflictResolve(cresult,description)) {
+        return data->generate_cancel_error();
+    }
+    cresult.assignResult(result,pool);
+    return SVN_NO_ERROR;
+#else
+    Q_UNUSED(result);
+    Q_UNUSED(description);
+    Q_UNUSED(baton);
+    Q_UNUSED(pool);
+    return svn_error_create (SVN_ERR_CANCELLED, NULL,"invalid subversion version.");
+#endif
+}
+
+bool ContextListener::contextConflictResolve(ConflictResult&result,const ConflictDescription&description)
+{
+    Q_UNUSED(description);
+#if  ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5) || (SVN_VER_MAJOR > 2))
+    result.setChoice(ConflictResult::ChoosePostpone);
+#else
+    Q_UNUSED(result);
+#endif
+    return true;
+}
+
 }
