@@ -51,23 +51,24 @@ namespace svn
     Exception (const char * message) throw ();
     Exception (const QString&message) throw();
 
-    ~Exception () throw ();
+    virtual ~Exception () throw ();
 
     /**
      * @return the exception message.
      */
-    const QString& msg() const;
+    virtual const QString& msg() const;
 
     /**
      * @return the outermost error code.
      */
-    const apr_status_t apr_err () const;
+    apr_status_t apr_err () const;
 
     static QString error2msg(svn_error_t*error);
 
   protected:
     struct Data;
     Data * m;
+    void setMessage(const QString&);
 
   private:
 
@@ -103,6 +104,11 @@ namespace svn
     */
     ClientException (const char*msg) throw ();
 
+   /**
+    * Constructor
+    */
+    ClientException (const QString&message) throw();
+
     /**
      * Copy constructor
      */
