@@ -1,4 +1,4 @@
-/* 
+/*
  * Port for usage with qt-framework and development for kdesvn
  * (C) 2005-2007 by Rajko Albrecht
  * http://kdesvn.alwins-world.de
@@ -32,14 +32,17 @@
 #define _SVNCPP_LOG_ENTRY_H_
 
 #include "svnqt/svnqt_defines.hpp"
+#include "svnqt/datetime.hpp"
 
 //Qt
 #include <qglobal.h>
 
 #if QT_VERSION < 0x040000
 
+#include <qglobal.h>
 #include <qstring.h>
 #include <qvaluelist.h>
+#include <qmap.h>
 
 #else
 
@@ -52,6 +55,7 @@
 
 // subversion api
 #include "svn_types.h"
+#include "svn_version.h"
 
 namespace svn
 {
@@ -84,14 +88,9 @@ namespace svn
     //! future use or useful in backends
     QString copyToPath;
 
-#if QT_VERSION < 0x040000
-    svn_revnum_t copyFromRevision;
+    QLONG copyFromRevision;
     //! future use or useful in backends
-    svn_revnum_t copyToRevision;
-#else
-    qlonglong copyFromRevision;
-    qlonglong copyToRevision;
-#endif
+    QLONG copyToRevision;
   };
 
 #if QT_VERSION < 0x040000
@@ -109,26 +108,26 @@ namespace svn
               const char * author,
               const char * date,
               const char * message);
-    void setDate(const char*date);
-#if QT_VERSION < 0x040000
-    //! if -1 the entry is a fake entry and not real usable!
-    svn_revnum_t revision;
-    apr_time_t date;
-#else
-    qlonglong revision;
-    qlonglong date;
+#if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
+    LogEntry(svn_log_entry_t*);
 #endif
+    void setDate(const char*date);
+
+    //! if -1 the entry is a fake entry and not real usable!
+    QLONG revision;
+    QLONG date;
     QString author;
     QString message;
     LogChangePathEntries changedPaths;
+    QLIST<QLONG> m_MergedInRevisions;
   };
 }
 
-SVNQT_EXPORT QDataStream& operator<<(QDataStream&s,const svn::LogEntry&r);
-SVNQT_EXPORT QDataStream& operator<<(QDataStream&s,const svn::LogChangePathEntry&r);
+SVNQT_EXPORT QDataStream &operator<<(QDataStream&s,const svn::LogEntry&r);
+SVNQT_EXPORT QDataStream &operator<<(QDataStream&s,const svn::LogChangePathEntry&r);
 
-SVNQT_EXPORT QDataStream& operator>>(QDataStream&s,svn::LogEntry&r);
-SVNQT_EXPORT QDataStream& operator>>(QDataStream&s,svn::LogChangePathEntry&r);
+SVNQT_EXPORT QDataStream &operator>>(QDataStream&s,svn::LogEntry&r);
+SVNQT_EXPORT QDataStream &operator>>(QDataStream&s,svn::LogChangePathEntry&r);
 
 #endif
 /* -----------------------------------------------------------------
@@ -136,4 +135,3 @@ SVNQT_EXPORT QDataStream& operator>>(QDataStream&s,svn::LogChangePathEntry&r);
  * eval: (load-file "../../rapidsvn-dev.el")
  * end:
  */
-
