@@ -39,6 +39,10 @@ namespace svn
   apr_pool_t *
   Pool::pool_create (apr_pool_t * parent)
   {
+    if (!s_initialized) {
+        apr_pool_initialize();
+        s_initialized=true;
+    }
     return svn_pool_create (parent);
   }
 
@@ -51,7 +55,7 @@ namespace svn
   {
     if(m_pool)
     {
-      svn_pool_destroy (m_pool);
+        svn_pool_destroy (m_pool);
     }
   }
 
