@@ -20,8 +20,8 @@
 #ifndef SVNREPOSITORY_H
 #define SVNREPOSITORY_H
 
-// Ignore MSVC 7 & 2005 compiler warning: C++ exception specification
-#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1410
+// Ignore MSVC 7, 2005 & 2008 compiler warning: C++ exception specification
+#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1550
 #pragma warning (disable: 4290)
 #endif
 
@@ -75,7 +75,7 @@ public:
      * \param _pre_1_4_compat Create repository compatibel to version earlier than 1.4 (only used with subversion 1.4)
      */
     void CreateOpen(const QString&path, const QString&fstype, bool _bdbnosync = false,
-        bool _bdbautologremove = true, bool _pre_1_4_compat=false) throw (ClientException);
+                    bool _bdbautologremove = true, bool _pre_1_4_compat=false, bool _pre_1_5_compat=false) throw (ClientException);
     //! dump content of repository to a file
     /*!
         The repository must opend before. Progress message go trough the assigned svn::repository::RepositoryListener object.
