@@ -31,8 +31,10 @@
 // svncpp
 #include "status.hpp"
 #include "svnqt/svnqt_defines.hpp"
+#include "svnqt/path.hpp"
+#include "svnqt/url.hpp"
 
-//#include <assert.h>
+#include "svn_path.h"
 
 namespace svn
 {
@@ -56,6 +58,8 @@ namespace svn
     void
     init(const QString&url,const InfoEntry&src);
 
+    void setPath(const QString&);
+
     QString m_Path;
     bool m_isVersioned;
     bool m_hasReal;
@@ -75,10 +79,20 @@ namespace svn
   {
   }
 
+  void Status_private::setPath(const QString&aPath)
+  {
+    Pool pool;
+    if (!Url::isValid(aPath)) {
+        m_Path = aPath;
+    } else {
+        const char * int_path = svn_path_uri_decode(aPath.TOUTF8(), pool.pool () );
+        m_Path = QString::FROMUTF8(int_path);
+    }
+  }
+
   void Status_private::init (const QString&path, const svn_wc_status2_t * status)
   {
-    m_Path = path;
-
+    setPath(path);
     if (!status)
     {
       m_isVersioned = false;
@@ -119,7 +133,7 @@ namespace svn
   void
   Status_private::init (const QString&path,const Status_private&src)
   {
-    m_Path=path;
+    setPath(path);
     m_Lock=src.m_Lock;
     m_entry=src.m_entry;
     m_isVersioned=src.m_isVersioned;
@@ -135,7 +149,7 @@ namespace svn
   void Status_private::init(const QString&url,const DirEntryPtr&src)
   {
     m_entry=Entry(url,src);
-    m_Path=url;
+    setPath(url);
     _text_status = svn_wc_status_normal;
     _prop_status = svn_wc_status_normal;
     if (src) {
@@ -151,7 +165,7 @@ namespace svn
   void Status_private::init(const QString&url,const InfoEntry&src)
   {
     m_entry=Entry(url,src);
-    m_Path=url;
+    setPath(url);
     m_Lock=src.lockEntry();
     _text_status = svn_wc_status_normal;
     _prop_status = svn_wc_status_normal;
@@ -221,59 +235,59 @@ namespace svn
   {
       return m_Data->m_Lock;
   }
-    const svn_wc_status_kind
+    svn_wc_status_kind
     Status::reposPropStatus () const
     {
       return m_Data->_repos_prop_status;
     }
-    const svn_wc_status_kind
+    svn_wc_status_kind
     Status::reposTextStatus () const
     {
       return m_Data->_repos_text_status;
     }
-    const bool
+    bool
     Status::isSwitched () const
     {
       return m_Data->_switched != 0;
     }
-    const bool
+    bool
     Status::isCopied () const
     {
       return m_Data->_copied;
     }
 
-    const bool
+    bool
     Status::isLocked () const
     {
       return m_Data->m_Lock.Locked();
     }
 
-    const bool
+    bool
     Status::isModified()const
     {
         return textStatus()==svn_wc_status_modified||propStatus()==svn_wc_status_modified
                 ||textStatus ()==svn_wc_status_replaced;
     }
 
-    const bool
+    bool
     Status::isRealVersioned()const
     {
       return m_Data->m_hasReal;
     }
 
-    const bool
+    bool
     Status::isVersioned () const
     {
       return m_Data->m_isVersioned;
     }
 
-    const svn_wc_status_kind
+    svn_wc_status_kind
     Status::propStatus () const
     {
       return m_Data->_prop_status;
     }
 
-    const svn_wc_status_kind
+    svn_wc_status_kind
     Status::textStatus () const
     {
       return m_Data->_text_status;
