@@ -116,7 +116,7 @@ namespace svn
      *
      * @param pool Pool used for conversion
      */
-    const apr_array_header_t *
+    apr_array_header_t *
     array (const Pool & pool) const;
 
     /**
@@ -142,6 +142,7 @@ namespace svn
       return m_targets;
     }
 
+    const Path& operator [](size_t which)const;
     /**
      * returns one single target.
      * the first in the vector, if no parameter given if there are more
